# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: /var/cvsroot/gentoo-x86/net-www/apache/apache-1.3.33-r5.ebuild,v 1.1 2005/07/12 03:58:27 vericgar Exp $

# Gentoo ARCH teams
#
# Do NOT mark this ebuild as stable unless the corresponding mod_ssl package
# can also be marked as stable on your arch.
#
# Thanks,
# stuart@gentoo.org

inherit eutils fixheadtails

S=${WORKDIR}/${PN}_${PV}
DESCRIPTION="The Apache Web Server"
HOMEPAGE="http://www.apache.org http://www.modssl.org"
KEYWORDS="~alpha amd64 hppa ia64 ~mips ~ppc ppc64 sparc x86"
SRC_URI="mirror://apache/httpd/apache_${PV}.tar.gz
	http://dev.gentoo.org/~vericgar/dist/apache/old/apache-patches-1.3.33-20050711.tar.bz2"


# The mod_ssl archive is only for providing the EAPI patch in here.
# You should install the net-www/mod_ssl package for the actual DSO.

DEPEND="dev-lang/perl
	>=dev-libs/mm-1.1.3
	=sys-libs/db-1*
	!dev-libs/apr
	!dev-libs/apr-util"

LICENSE="Apache-2.0"
SLOT="1"



#Standard location for Gentoo Linux
DATADIR="/var/www"
src_unpack() {
	unpack ${A} || die
	cd ${S} || die

	EPATCH_SUFFIX="patch"
	epatch ${WORKDIR}/apache-patches-1.3.33/[0-2]* || die
	epatch ${FILESDIR}/patches/imedia/imedia-base-patch.patch || die
	
	#Obsolete 'head -1' and 'tail -1' calls.
	ht_fix_file src/Configure src/helpers/getuid.sh \
		src/helpers/fmn.sh src/helpers/buildinfo.sh

	# set a reasonable MM_CORE_PATH location..
	sed -i -e 's:logs/mm:/var/cache/apache-mm/mm:' \
		src/include/httpd.h
}

src_compile() {
	local myconf mycflags
	
	mycflags="${CFLAGS}"
	unset CFLAGS ; unset CXXFLAGS

	select_modules_config || die "determining modules"

	#-DBUFFERED_LOGS
	OPTIM="${mycflags} -DHARD_SERVER_LIMIT=${HARD_SERVER_LIMIT:=512} \
		-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64" \
	./configure \
		--prefix=/usr \
		--exec-prefix=/usr \
		--bindir=/usr/bin \
		--sbindir=/usr/sbin \
		--libexecdir=/usr/lib/apache \
		--mandir=/usr/share/man \
		--sysconfdir=/etc/httpd/conf \
		--datadir=${DATADIR} \
		--cgidir=${DATADIR}/cgi-bin \
		--iconsdir=${DATADIR}/icons \
		--htdocsdir=${DATADIR}/htdocs \
		--manualdir=/usr/share/doc/${PF}/manual \
		--includedir=/usr/include/apache \
		--localstatedir=/var \
		--runtimedir=/var/run \
		--logfiledir=/var/log/httpd \
		--proxycachedir=/var/cache/httpd \
		--serverroot=/etc/httpd \
		--target=httpd \
		--server-uid=nobody \
		--server-gid=nobody \
		--with-perl=/usr/bin/perl \
		--disable-rule=EXPAT \
		--enable-shared=access \
		--enable-shared=alias \
		--enable-shared=auth \
		--enable-shared=autoindex \
		--enable-shared=cgi \
		--enable-shared=dir \
		--enable-shared=env \
		--enable-shared=mime \
		${myconf} || die "bad ./configure"

	emake || die "compile problem"
}

src_install() {
	local myfile

	GID=`id -g apache`
	if [ -z "${GID}" ]; then
		einfo "Using default GID of 81 for Apache"
		GID=81
	fi

	make install-quiet root=${D} || die
	dodoc ABOUT_APACHE Announcement INSTALL* LICENSE* README* WARNING* \
		${FILESDIR}/robots.txt

	#protect the suexec binary
	fowners root:${GID} /usr/sbin/suexec
	fperms 4710 /usr/sbin/suexec

	# nice support scripts..
	for myfile in apacheaddmod apachedelmod \
		apachelogserverstatus apachesplitlogfile
	do
		exeinto /usr/sbin
		doexe ${FILESDIR}/$myfile
	done

	# setup links in /etc/apache..
	cd ${D}/etc/httpd
	ln -sf ../../usr/lib/apache modules
	# apxs needs this to pickup the right lib for install..
	ln -sf ../../usr/lib lib
	ln -sf ../../var/log/httpd logs
	ln -sf ../../usr/lib/apache-extramodules extramodules

	# drop in a convenient link to the manual
	dosym /usr/share/doc/${PF}/manual ${DATADIR}/htdocs/manual

	# deprecated config files, empty dirs..
	rm -f ${D}/etc/httpd/conf/apache.conf.default
	rm -f ${D}/etc/httpd/conf/access.conf*
	rm -f ${D}/etc/httpd/conf/srm.conf*

	# now the config files..
	insinto /etc/httpd/conf
	doins ${FILESDIR}/conf/httpd.conf
	doins ${FILESDIR}/conf/httpd.conf.mediabox
	doins ${FILESDIR}/conf/httpd.conf.minibox

	# Added by Jason Wever <weeve@gentoo.org>
	# A little sedfu to fix bug #7172 for sparc64s
	if [ ${ARCH} = "sparc" ]
	then
		sed -i -e '15a\AcceptMutex fcntl' \
		${D}/etc/apache/conf/apache.conf
	fi


	exeinto /etc/init.d ; newexe ${FILESDIR}/apache.rc6 apache
	#insinto /etc/conf.d ; newins ${FILESDIR}/apache.confd apache
	insinto /etc/httpd ; doins ${FILESDIR}/apache-builtin-mods
	insinto /etc/httpd/access ; doins ${FILESDIR}/access/.htpasswd
	insinto /etc/httpd/access ; doins ${FILESDIR}/access/.htaccess
	exeinto /etc/rcS.d ; newexe ${FILESDIR}/scripts/M30-httpd M30-httpd

	#empty dirs
	keepdir /var/cache/httpd /var/cache/httpd-mm /usr/lib/apache-extramodules /etc/httpd/conf/addon-modules /var/log/httpd
}

pkg_postinst() {
	# these are in baselayout now; it will not hurt to leave them here though
	# moved to pkg_postinst by jnelson, moved to pkg_preinst by lostlogic
	#getent group apache >/dev/null 2>&1
	#if [ $? -ne 0 ]; then
	#	groupadd -g 81 apache || die "problem adding group apache"
	#fi

	# usermod returns 2 on user-exists-but-no-flags-given
	#usermod apache &>/dev/null
	#if [ $? != 2 ]; then
	#getent passwd apache >/dev/null 2>&1
	#if [ $? -ne 0 ]; then
	#	useradd -u 81 -g apache -s /bin/false -d /var/www/localhost -c "apache" apache
	#	assert "problem adding user apache"
	#fi

	einfo
	einfo "Please remember to update your config files in /etc/httpd"
	einfo "as --datadir has been changed to ${DATADIR}!"
	einfo
}

parse_modules_config() {
	local filename=$1
	local name=""
	local dso=""
	local disable=""
	[ -f ${filename} ] || return 1
	einfo "Using ${filename} for builtins."
	for i in `cat $filename | sed "s/^#.*//"` ; do
		if [ $i == "-" ] ; then
			disable="true"
		elif [ -z "$name" ] && [ ! -z "`echo $i | grep "mod_"`" ] ; then
			name=`echo $i | sed "s/mod_//"`
		elif [ "$disable" ] && ( [ $i == "static" ] || [ $i == "shared" ] ) ; then
			MY_BUILTINS="${MY_BUILTINS} --disable-module=$name"
			name="" ; disable=""
		elif [ $i == "static" ] ; then
			MY_BUILTINS="${MY_BUILTINS} --enable-module=$name --disable-shared=$name"
			name="" ; disable=""
		elif [ $i == "shared" ] ; then
			MY_BUILTINS="${MY_BUILTINS} --enable-module=$name --enable-shared=$name"
			name="" ; disable=""
		fi
	done
}

select_modules_config() {
	parse_modules_config /etc/httpd/apache-builtin-mods || \
	parse_modules_config ${FILESDIR}/apache-builtin-mods || \
	return 1
}
